==> infinispan-server-runtime-11.0.15.Final-sources.jar: org/infinispan/server/configuration/SocketBindingConfigurationBuilder.java <==
package org.infinispan.server.configuration;

import org.infinispan.commons.configuration.Builder;
import org.infinispan.commons.configuration.attributes.AttributeSet;
import org.infinispan.server.Server;
import org.infinispan.server.network.NetworkAddress;
import org.infinispan.server.network.SocketBinding;

public class SocketBindingConfigurationBuilder implements Builder<SocketBindingConfiguration> {

   private final AttributeSet attributes;
   private final ServerConfigurationBuilder server;
   private SocketBinding socketBinding;

   SocketBindingConfigurationBuilder(ServerConfigurationBuilder server) {
      this.server = server;
      attributes = SocketBindingConfiguration.attributeDefinitionSet();
   }

   public SocketBindingConfigurationBuilder binding(String name, int port, String interfaceName) {
      attributes.attribute(SocketBindingConfiguration.NAME).set(name);
      attributes.attribute(SocketBindingConfiguration.PORT).set(port);
      if (!server.interfaces().exists(interfaceName)) {
         throw Server.log.unknownInterface(interfaceName);
      }
      attributes.attribute(SocketBindingConfiguration.INTERFACE).set(name);
      NetworkAddress networkAddress = server.interfaces().getNetworkAddress(interfaceName);
      int offset = server.socketBindings().offset();
      this.socketBinding = new SocketBinding(name, networkAddress, port + offset);
      return this;
   }

   SocketBinding getSocketBinding() {
      return socketBinding;
   }

   @Override
   public void validate() {
   }

   @Override
   public SocketBindingConfiguration create() {
      return new SocketBindingConfiguration(attributes.protect(), socketBinding);
   }

   @Override
   public SocketBindingConfigurationBuilder read(SocketBindingConfiguration template) {
      this.attributes.read(template.attributes());
      return this;
   }

}

==> infinispan-server-runtime-14.0.12.Final-sources.jar: org/infinispan/server/configuration/SocketBindingConfigurationBuilder.java <==
package org.infinispan.server.configuration;

import org.infinispan.commons.configuration.Builder;
import org.infinispan.commons.configuration.attributes.AttributeSet;

public class SocketBindingConfigurationBuilder implements Builder<SocketBindingConfiguration> {

   private final AttributeSet attributes;
   private final ServerConfigurationBuilder server;

   SocketBindingConfigurationBuilder(ServerConfigurationBuilder server) {
      this.server = server;
      attributes = SocketBindingConfiguration.attributeDefinitionSet();
   }

   @Override
   public AttributeSet attributes() {
      return attributes;
   }

   public SocketBindingConfigurationBuilder binding(String name, int port, String interfaceName) {
      attributes.attribute(SocketBindingConfiguration.NAME).set(name);
      attributes.attribute(SocketBindingConfiguration.PORT).set(port);
      attributes.attribute(SocketBindingConfiguration.INTERFACE).set(interfaceName);
      return this;
   }

   String interfaceName() {
      return attributes.attribute(SocketBindingConfiguration.INTERFACE).get();
   }

   @Override
   public SocketBindingConfiguration create() {
      throw new UnsupportedOperationException();
   }

   @Override
   public SocketBindingConfigurationBuilder read(SocketBindingConfiguration template) {
      this.attributes.read(template.attributes());
      return this;
   }

   public SocketBindingConfiguration create(InterfaceConfiguration interfaceConfiguration) {
      return new SocketBindingConfiguration(attributes.protect(), interfaceConfiguration);
   }
}
